@@ -385,11 +385,11 @@ class VQGanVAE(nn.Module):
 
         return vae_copy.to(device)
 
-    def state_dict(self, **kwargs):
+    def state_dict(self, *args, **kwargs):
         # make sure VGG is not saved in state dictionary
         vgg = self.vgg
         delattr(self, 'vgg')
-        state_dict = super().state_dict(**kwargs)
+        state_dict = super().state_dict(*args, **kwargs)
         self.vgg = vgg
         return state_dict
 
